import { EventEmitter, Component, ViewEncapsulation, ElementRef, Input, Output, NgModule } from '@angular/core';
import * as GC from '@grapecity/spread-sheets';
import '@grapecity/spread-sheets-designer';
import { Observable } from 'rxjs';
import { CommonModule } from '@angular/common';

import * as ɵngcc0 from '@angular/core';
class DesignerComponent {
    constructor(elRef) {
        this.elRef = elRef;
        this.designerInitialized = new EventEmitter();
    }
    ngAfterViewInit() {
        const dom = this.elRef.nativeElement;
        this.designer = new GC.Spread.Sheets.Designer.Designer(dom.querySelector('div'));
        const { config } = this.props;
        if (config) {
            this.setConfig(config);
        }
        this.designer.refresh();
        this.designerInitialized.emit({ designer: this.designer });
    }
    setStyleInfo(styleinfo) {
        if (styleinfo instanceof Observable) {
            let styleObChange = styleinfo.subscribe({
                next: arg => this.updateStyleInfo(arg),
                error: e => console.error(e),
                complete: () => styleObChange.unsubscribe()
            });
        }
        else {
            this.styleInfo = styleinfo;
        }
    }
    setConfig(config) {
        if (config instanceof Observable) {
            let configObChange = config.subscribe({
                next: arg => this.updateConfig(arg),
                error: e => console.error(e),
                complete: () => configObChange.unsubscribe()
            });
        }
        else {
            this.designer.setConfig(config);
        }
    }
    updateStyleInfo(styleInfo) {
        this.designer.Spread.suspendPaint();
        this.styleInfo = styleInfo;
        this.designer.refresh();
        this.designer.Spread.resumePaint();
    }
    updateConfig(config) {
        this.designer.Spread.suspendPaint();
        this.designer.setConfig(config);
        this.designer.refresh();
        this.designer.Spread.resumePaint();
    }
    ngOnChanges(changes) {
        let property = changes.props.currentValue;
        if (!this.designer) {
            if (property.styleInfo) {
                this.setStyleInfo(changes.props.currentValue.styleInfo);
            }
        }
        else {
            if (property.styleInfo) {
                this.updateStyleInfo(changes.props.currentValue.styleInfo);
            }
            if (property.config) {
                this.updateConfig(changes.props.currentValue.config);
            }
        }
    }
    ngOnDestroy() {
        this.designer.dispose();
    }
}
DesignerComponent.ɵfac = function DesignerComponent_Factory(t) { return new (t || DesignerComponent)(ɵngcc0.ɵɵdirectiveInject(ɵngcc0.ElementRef)); };
DesignerComponent.ɵcmp = ɵngcc0.ɵɵdefineComponent({ type: DesignerComponent, selectors: [["designer"]], inputs: { props: "props" }, outputs: { designerInitialized: "designerInitialized" }, features: [ɵngcc0.ɵɵNgOnChangesFeature], decls: 1, vars: 2, consts: [["id", "gc-designer-container", 1, "designer"]], template: function DesignerComponent_Template(rf, ctx) { if (rf & 1) {
        ɵngcc0.ɵɵelement(0, "div", 0);
    } if (rf & 2) {
        ɵngcc0.ɵɵstyleMap(ctx.styleInfo);
    } }, encapsulation: 2 });
DesignerComponent.ctorParameters = () => [
    { type: ElementRef }
];
DesignerComponent.propDecorators = {
    props: [{ type: Input }],
    designerInitialized: [{ type: Output }]
};
/*@__PURE__*/ (function () { ɵngcc0.ɵsetClassMetadata(DesignerComponent, [{
        type: Component,
        args: [{
                selector: 'designer',
                template: `
  <div id= "gc-designer-container" class="designer" [style]="styleInfo">
  </div>
  `,
                encapsulation: ViewEncapsulation.None
            }]
    }], function () { return [{ type: ɵngcc0.ElementRef }]; }, { designerInitialized: [{
            type: Output
        }], props: [{
            type: Input
        }] }); })();

class DesignerModule {
}
DesignerModule.ɵmod = ɵngcc0.ɵɵdefineNgModule({ type: DesignerModule });
DesignerModule.ɵinj = ɵngcc0.ɵɵdefineInjector({ factory: function DesignerModule_Factory(t) { return new (t || DesignerModule)(); }, imports: [[
            CommonModule
        ]] });
(function () { (typeof ngJitMode === "undefined" || ngJitMode) && ɵngcc0.ɵɵsetNgModuleScope(DesignerModule, { declarations: function () { return [DesignerComponent]; }, imports: function () { return [CommonModule]; }, exports: function () { return [DesignerComponent]; } }); })();
/*@__PURE__*/ (function () { ɵngcc0.ɵsetClassMetadata(DesignerModule, [{
        type: NgModule,
        args: [{
                imports: [
                    CommonModule
                ],
                declarations: [DesignerComponent],
                exports: [DesignerComponent] //新添加的部分
            }]
    }], null, null); })();

/**
 * Generated bundle index. Do not edit.
 */

export { DesignerModule, DesignerComponent as ɵa };

//# sourceMappingURL=grapecity-spread-sheets-designer-angular.js.map