import { EventEmitter, Component, ViewEncapsulation, ElementRef, Input, Output, NgModule } from '@angular/core';
import * as GC from '@grapecity/spread-sheets';
import '@grapecity/spread-sheets-designer';
import { Observable } from 'rxjs';
import { CommonModule } from '@angular/common';

class DesignerComponent {
    constructor(elRef) {
        this.elRef = elRef;
        this.designerInitialized = new EventEmitter();
    }
    ngAfterViewInit() {
        const dom = this.elRef.nativeElement;
        this.designer = new GC.Spread.Sheets.Designer.Designer(dom.querySelector('div'));
        const { config } = this.props;
        if (config) {
            this.setConfig(config);
        }
        this.designer.refresh();
        this.designerInitialized.emit({ designer: this.designer });
    }
    setStyleInfo(styleinfo) {
        if (styleinfo instanceof Observable) {
            let styleObChange = styleinfo.subscribe({
                next: arg => this.updateStyleInfo(arg),
                error: e => console.error(e),
                complete: () => styleObChange.unsubscribe()
            });
        }
        else {
            this.styleInfo = styleinfo;
        }
    }
    setConfig(config) {
        if (config instanceof Observable) {
            let configObChange = config.subscribe({
                next: arg => this.updateConfig(arg),
                error: e => console.error(e),
                complete: () => configObChange.unsubscribe()
            });
        }
        else {
            this.designer.setConfig(config);
        }
    }
    updateStyleInfo(styleInfo) {
        this.designer.Spread.suspendPaint();
        this.styleInfo = styleInfo;
        this.designer.refresh();
        this.designer.Spread.resumePaint();
    }
    updateConfig(config) {
        this.designer.Spread.suspendPaint();
        this.designer.setConfig(config);
        this.designer.refresh();
        this.designer.Spread.resumePaint();
    }
    ngOnChanges(changes) {
        let property = changes.props.currentValue;
        if (!this.designer) {
            if (property.styleInfo) {
                this.setStyleInfo(changes.props.currentValue.styleInfo);
            }
        }
        else {
            if (property.styleInfo) {
                this.updateStyleInfo(changes.props.currentValue.styleInfo);
            }
            if (property.config) {
                this.updateConfig(changes.props.currentValue.config);
            }
        }
    }
    ngOnDestroy() {
        this.designer.dispose();
    }
}
DesignerComponent.decorators = [
    { type: Component, args: [{
                selector: 'designer',
                template: `
  <div id= "gc-designer-container" class="designer" [style]="styleInfo">
  </div>
  `,
                encapsulation: ViewEncapsulation.None
            },] }
];
DesignerComponent.ctorParameters = () => [
    { type: ElementRef }
];
DesignerComponent.propDecorators = {
    props: [{ type: Input }],
    designerInitialized: [{ type: Output }]
};

class DesignerModule {
}
DesignerModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [DesignerComponent],
                exports: [DesignerComponent] //新添加的部分
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { DesignerModule, DesignerComponent as ɵa };
//# sourceMappingURL=grapecity-spread-sheets-designer-angular.js.map
