# SpreadJS Designer Component - Getting Started

The SpreadJS Designer allow users to customize their spreadsheet UI using the built in dialogs and options. The Designer source is a shell that allows you the developer to attach an existing Workbook instance and wraps it into the Designer interface. The ribbon options can be fully customized per your application’s needs. Similarly, the included panels can be customized or added as needed.

Follow the steps laid out in this guide to add the designer components to a project and easily customize them.


**Referencing Files**
---------------------

The Designer component is only dependent on SpreadJS and requires referencing the SpreadJS CSS and JS files as follows:


*   gc.spread.sheets.xx.x.x.css
*   gc.spread.sheets.charts.xx.x.x.min.js
*   gc.spread.sheets.shapes.xx.x.x.min.js
*   gc.spread.sheets.print.xx.x.x.min.js
*   gc.spread.sheets.barcode.xx.x.x.min.js
*   gc.spread.sheets.pdf.xx.x.x.min.js
*   gc.spread.excelio.xx.x.x.min.js

The SpreadJS Designer component also has its own CSS and JS files::

*   gc.spread.sheets.designer.xx.x.x.min.css
*   gc.spread.sheets.designer.resource.en.xx.x.x.min.js
*   gc.spread.sheets.designer.xx.x.x.min.js

These files can be referenced in an HTML file as follows:
```js
<link rel="styleSheet" href="gc.spread.sheets.xx.x.x.css"/>
<link rel="styleSheet" href="gc.spread.sheets.designer.xx.x.x.min.css"/>
<script src="gc.spread.sheets.all.xx.x.x.min.js" type="text/javascript"></script>
<script src="gc.spread.sheets.charts.xx.x.x.min.js" type="text/javascript"></script>
<script src="gc.spread.sheets.shapes.xx.x.x.min.js" type="text/javascript"></script>
<script src="gc.spread.sheets.print.xx.x.x.min.js" type="text/javascript"></script>
<script src="gc.spread.sheets.barcode.xx.x.x.min.js" type="text/javascript"></script>
<script src="gc.spread.sheets.pdf.xx.x.x.min.js" type="text/javascript"></script>
<script src="gc.spread.excelio.xx.x.x.min.js" type="text/javascript"></script>
<script src="gc.spread.sheets.designer.resource.en.xx.x.x.min.js " type="text/javascript"></script>
<script src="gc.spread.sheets.designer.xx.x.x.min.js" type="text/javascript"></script>
```

Initializing Components
-----------------------

The Designer can be hosted within a single DOM element in the page body:
```js
<div id="designerHost" style="width:100%; height:360px;border: 1px solid gray;"></div>
```

Before initializing the components, the license for SpreadJS must be set:
```js
GC.Spread.Sheets.LicenseKey = "XXXX";
```
Once the license is set, the designer instance can be initialized with a single line:
```js
var designer = new GC.Spread.Sheets.Designer.Designer(document.getElementById("designerHost"));
```
Customizing the Designer
------------------------

The SpreadJS Designer Component can easily be customized and embedded into your web applications. To begin, let's first review the **GC.Spread.Sheets.Designer.Designer** API which has three parameters:


*   "designerHost" - an HTMLElement representing the host element of the designer
*   "designerConfig" - an Object representing a customizable configuration JSON of the layout
*   "spread" - the GC.Spread.Sheets.Workbook instance that represents the SpreadJS instance connected to the designer

The last two parameters are optional. If they are not specified, the designer will use the default configuration and generate a new workbook. The main parameter used for the customization is  **designerConfig**.

### Parts of the Designer

To better understand the layout and terminology, refer to the following diagram:

![](http://cdn.grapecity.com/spreadjs/Designer2.png)

Open and edit the  **Config.js** file to customize the layout structure using the details below:

*   "ribbon"
    *   HOME
        *   "id":"home"
        *   "text":"HOME"
        *   "buttonGroups":
            *   Undo
                *   "label":"Undo"
                *   "thumbnailClass":"ribbon-thumbnail-undoredo"
                *   "commandGroup":
                    *   "children"
                        *   "Commands"
            *   Clipboard
            *   Fonts
            *   ...
    *   INSERT
    *   FORMULAS
    *   DATA
    *   VIEW
    *   SETTINGS
    *   DESIGN
    *   ...
*   "contextMenu"
    *   "designer.cut"
    *   "designer.copy"
    *   "separator"
    *   "designer.insert_dialog"
    *   "gc.spread.contextMenu.insertColumns"
    *   "gc.spread.contextMenu.rowHeaderinsertCopiedCells"
    *   "shape-command-group"
    *   "designer.more-functions"
    *   ...
*   "fileMenu"
    *   "fileMenuButton"
*   "sidePanels"
    *   formulaBarPanel
        *   "position":"top"
        *   "allowResize":true
        *   "command":"formulaBarPanel"
        *   "uiTemplate":"formulaBarTemplate"
        *   ...
    *   fieldListTreePanel
    *   statusBarPanel
    *   fileMenuPanel
    *   shapePanel
    *   columnChartPanel
    *   ...

### Notes to Remember:

*   The first level, including **ribbon**, **contextMenu**, **fileMenu**, and **sidePanels** can only be deleted, but not modified or added.
*   The second level and corresponding sub-levels can customized

### Customizing Commands

Custom commands can be created as objects using the following properties:

*   Title - the title of the command
*   Text - the text that is displayed
*   IconClass - the css style class that is used for the button
*   BigButton - a boolean that determines if the button should be large or not
*   CommandName - the name of the command used in the command map
*   Execute - the function that fires when the command is executed

Add these to the config's commandMap object:

```js
config.commandMap = {
	<CommandName>: <name of custom command variable>
}
```

Then add the command into the ribbon under the "commands" property:
```js
{
    "label":"NewDesigner",
    "thumbnailClass":<commandText>,
    "commandGroup":{
        "children":[
            {
                "direction":"vertical",
                "commands":[
                    <CommandName>
                ]
            }
        ]
    }
}
```


Example
---------------------

As an example to show how the customization works, the following adds a command option called "Save Data" which could save changed data back to a server. Begin by using the following steps:

1.  Create a button within the **buttonGroups** field in the **HOME** tab of the ribbon:
```js
    "ribbon":[
    	{
    		"id":"home",
    		"text":"HOME",
    		"buttonGroups":[
    			// Custom "Save Data" button
    			{
    				"label":"Save Data",
    				"thumbnailClass":"",
    				"commandGroup":{
    					"children":[
    						{
    							"direction":"vertical",
    							"commands":[
    								"cmdSaveData"
    							]
    						}
    					]
    				}
    			},
    			(...)
    		]
    		(...)
    	}
    ]
```


2.  Instead of creating a command and then setting it in the **commandMap**, we can simply add the corresponding command to **commandMap** in the **Config.js** file directly as follows:
```js
    config.commandMap = {
    	cmdSaveData: {
    		title: "Save data to server",
    		text: "Save",
    		iconClass: "cmdSaveData",
    		bigButton: "true",
    		commandName: "cmdSaveData",
    		execute: async (context, propertyName, fontItalicChecked) => {
    			// Customize operation
    			<Code to save to database here>
    			alert('Data saved successfully.');
    		}
    	}
    }
```
    The CSS style can also be set for that command within the designer's CSS file:
```css
    .cmdSaveData {
    	background-image: url('./saveData.png');
    	background-size: 35px 35px;
    }
```


3.  Finally, pass the above customized JSON parameter in when you create the Designer instance:
```js
    var designer = new GC.Spread.Sheets.Designer.Designer(document.getElementById("designerHost"), config);
```